import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ManifestConfig extends cdktf.TerraformMetaArguments {
    /**
     * A Kubernetes manifest describing the desired state of the resource in HCL format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#manifest Manifest#manifest}
     *
     * @stability stable
     */
    readonly manifest: {
        [key: string]: any;
    };
    /**
     * The resulting resource state, as returned by the API server after applying the desired state from `manifest`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#object Manifest#object}
     *
     * @stability stable
     */
    readonly object?: {
        [key: string]: any;
    };
    /**
     * A map of attribute paths and desired patterns to be matched.
     *
     * After each apply the provider will wait for all attributes listed here to reach a value that matches the desired pattern.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#wait_for Manifest#wait_for}
     *
     * @stability stable
     */
    readonly waitFor?: ManifestWaitFor;
}
/**
 * @stability stable
 */
export interface ManifestWaitFor {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html#fields Manifest#fields}.
     *
     * @stability stable
     */
    readonly fields?: {
        [key: string]: string;
    };
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html kubernetes_manifest}.
 *
 * @stability stable
 */
export declare class Manifest extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/manifest.html kubernetes_manifest} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ManifestConfig);
    private _manifest;
    /**
     * @stability stable
     */
    get manifest(): {
        [key: string]: any;
    };
    /**
     * @stability stable
     */
    set manifest(value: {
        [key: string]: any;
    });
    /**
     * @stability stable
     */
    get manifestInput(): {
        [key: string]: any;
    };
    private _object?;
    /**
     * @stability stable
     */
    get object(): {
        [key: string]: any;
    };
    /**
     * @stability stable
     */
    set object(value: {
        [key: string]: any;
    });
    /**
     * @stability stable
     */
    resetObject(): void;
    /**
     * @stability stable
     */
    get objectInput(): {
        [key: string]: any;
    } | undefined;
    private _waitFor?;
    /**
     * @stability stable
     */
    get waitFor(): ManifestWaitFor;
    /**
     * @stability stable
     */
    set waitFor(value: ManifestWaitFor);
    /**
     * @stability stable
     */
    resetWaitFor(): void;
    /**
     * @stability stable
     */
    get waitForInput(): ManifestWaitFor | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
